@@ -1,3 +1,3 @@
-from .doeUtilities import addTreatments
+from .doeUtilities import addTreatments, subgroupOfDefining
 from .graphs import (FDS_Plot, calculateInteractions, calculateMainEffects,
                      getModelMatrix, interactionPlot, mainEffectsPlot)
